/*
 * SeamistAuthenticationToken.java
 *
 * Created on April 29, 2004, 3:31 PM
 */

package net.seamist.service;

import java.io.Serializable;

import java.security.Principal;

import java.util.Iterator;
import java.util.Set;

/**
 * The <CODE>SeamistAuthenticationToken</CODE> holds the user's ID and 
 * permissions. An instance of this class is given to the client once he has 
 * been successfully authenticated.
 * @author Victor R. Cardona
 * @version $Revision: 1.1.1.1 $, $Date: 2004/05/10 20:28:08 $
 */
public class SeamistAuthenticationToken implements Serializable, Principal {
    
    /**
     * Holds value of property id.
     */
    private Integer id;
    
    /**
     * Holds value of property name.
     */
    private String name;
    
    /**
     * Holds value of property roles.
     */
    private Set roles;
    
    /**
     * Holds value of property status.
     */
    private String status;
    
    /**
     * Constructs a new instance of <CODE>SeamistAuthenticationToken</CODE> 
     * with the specified ID, name, permissions, and new account flag.
     * @param id the user's account identifier.
     * @param name the account holder's first name.
     * @param roles the account holder's permissions.
     * @param newAccount flag indicating if this is a new account.
     */    
    public SeamistAuthenticationToken(Integer id, String name, Set roles, String status) {
        this.id = id;
        this.name = name;
        this.roles = roles;
        this.status = status;
    }
    
    /**
     * Getter for property id.
     * @return Value of property id.
     */
    public Integer getId() {
        return this.id;
    }
    
    /**
     * Getter for property name.
     * @return Value of property name.
     */
    public String getName() {
        return this.name;
    }
    
    /**
     * Getter for property roles.
     * @return Value of property roles.
     */
    public Set getRoles() {
        return this.roles;
    }
    
    /**
     * Getter for property newAccount.
     * @return Value of property newAccount.
     */
    public String getStatus() {
        return this.status;
    }
    
    /**
     * Provides a hashed numeric representation of the object.
     * @return an int holding the hashed number for this object.
     */    
    public int hashCode() {
        return toString().hashCode();
    }
    
    /**
     * Determines whether this object, and the specified object are equal.
     * @param obj the object used for comparison.
     * @return true if the objects are equal, otherwise false.
     */    
    public boolean equals(Object obj) {
        return this.toString().equals(obj.toString());
    }
    
    /**
     * Creates a String representation of the object.
     * @return a string representing the object.
     */    
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        
        buffer.append(id);
        buffer.append(", ");
        buffer.append(name);
        
        Iterator iter = roles.iterator();
        while (iter.hasNext()) {
            buffer.append(", ");
            buffer.append(iter.next());
        }
        
        return buffer.toString();
    }
    
    /**
     * Checks to see if a user has the specified role.
     * @param role the role to check for.
     * @return true if the user has that role, otherwise false.
     */    
    public boolean isUserInRole(String role) {
        return roles.contains((String) role);
    }
    
}
